@@ -18,7 +18,7 @@ from .functions import get_client_and_project, get_date, get_project_number
 font_path = "9999_BID_AMS/AMS-VFB_Fonts"
 
 logo_path = "9999_BID_AMS/AMS_Logo's/RGB/Animotions_Logo_02_RGB.png"
-
+logo_path_cover_page = "9999_BID_AMS/AMS_Logo's/RGB/Animotions_Logo_02_RGB_TextOnly.png"
 proj_dir_windows = "X:"
 proj_dir_macos = "/Volumes/ams-fileserver/"
 
@@ -32,10 +32,14 @@ frame_height = 170
 
 def get_cwd():
     cwd = os.getcwd()
-    if cwd[0] != 'X':
+    if cwd[0] != 'X' and platform.system() == "Windows":
         click.secho("Please run the tool in the X:/ drive")
         return None
 
+    if platform.system() != "Windows" and "ams-fileserver" not in cwd:
+        click.secho("Try running the briefing tool inside X")
+        return None
+
     if len(cwd) == 3:
         click.secho('Please run tool inside a project folder')
         return None
@@ -45,6 +49,7 @@ def get_cwd():
 
 def main():
     logo = dir.joinpath(logo_path)
+    cover_logo = dir.joinpath(logo_path_cover_page)
     font_dir = dir.joinpath(font_path)
     click.echo(f"🥰 Let's create a briefing {os.getlogin()}!")
     pdf = FPDF(orientation='L', format='A4')
@@ -69,7 +74,7 @@ def main():
 
     project_name = input("🙏 Type in the project name: ")
 
-    create_cover_page(pdf)
+    create_cover_page(pdf, cover_logo)
     create_project_cover(pdf, project_name)
     pdf.set_subject(project_name)
     pdf.set_title(f"Briefing - {project_name}")
